@@ -1,6 +1,8 @@
+from django.conf import settings
 from django.utils import unittest
 from django.utils.translation import activate
 from django import template
+from django.contrib.auth.models import Permission
 from django.core import urlresolvers
 
 from sitetree.models import Tree, TreeItem
@@ -172,7 +174,10 @@ class TreeItemModelTest(unittest.TestCase):
 
     def test_context_proc_required(self):
         context = template.Context()
+        old_debug = settings.DEBUG
+        settings.DEBUG = True
         self.assertRaises(SiteTreeError, self.sitetree.menu, 'tree1', 'trunk', context)
+        settings.DEBUG = old_debug
 
     def test_menu(self):
         menu = self.sitetree.menu('tree1', 'trunk', get_mock_context(path='/about/'))
@@ -445,3 +450,49 @@ class DynamicTreeTest(unittest.TestCase):
         self.assertEqual(len(sitetree_items), 3)
         children = self.sitetree.get_children('dynamic', sitetree_items[0])
         self.assertEqual(len(children), 1)
+
+
+class UtilsItemTest(unittest.TestCase):
+
+    def test_permission_any(self):
+        i1 = item('root', 'url')
+        self.assertEqual(i1.access_perm_type, i1.PERM_TYPE_ALL)
+
+        i2 = item('root', 'url', perms_mode_all=True)
+        self.assertEqual(i2.access_perm_type, i1.PERM_TYPE_ALL)
+
+        i3 = item('root', 'url', perms_mode_all=False)
+        self.assertEqual(i3.access_perm_type, i1.PERM_TYPE_ANY)
+
+    def test_permissions_none(self):
+        i1 = item('root', 'url')
+        self.assertEqual(i1.permissions, [])
+
+    def test_int_permissions(self):
+        i1 = item('root', 'url', access_by_perms=[1, 2, 3])
+        self.assertEqual(i1.permissions, [1, 2, 3])
+
+    def test_valid_string_permissions(self):
+        perm = Permission.objects.all()[0]
+        perm_name = "{}.{}".format(perm.content_type.app_label, perm.codename)
+
+        i1 = item('root', 'url', access_by_perms=perm_name)
+        self.assertEqual(i1.permissions, [perm])
+
+    def test_perm_obj_permissions(self):
+        perm = Permission.objects.all()[0]
+
+        i1 = item('root', 'url', access_by_perms=perm)
+        self.assertEqual(i1.permissions, [perm])
+
+    def test_bad_string_permissions(self):
+        self.assertRaises(ValueError, item, 'root', 'url', access_by_perms='bad name')
+
+    def test_access_restricted(self):
+        # Test that default is False
+        i0 = item('root', 'url', access_by_perms=1)
+        self.assertEqual(i0.access_restricted, True)
+
+        # True is respected
+        i1 = item('root', 'url')
+        self.assertEqual(i1.access_restricted, False)
